pub struct ConstantLocalLinearAcceleration(pub Vector);Expand description
A component for applying a constant linear acceleration to a dynamic rigid body in local space. The unit is typically m/s².
The acceleration persists across time steps, and is accumulated with other accelerations. This can be useful for simulating constant linear accelerations like rocket thrust, or other local acceleration effects.
See the module-level documentation for more general information about forces in Avian.
Example
commands.spawn((
RigidBody::Dynamic,
Collider::capsule(0.5, 1.0),
// Apply a constant linear acceleration of 10.0 m/s² in the positive Y direction in local space.
ConstantLocalLinearAcceleration::new(0.0, 10.0, 0.0),
));Related Types
Forces: A helperQueryDatafor applying forces, impulses, and acceleration to entities.ConstantLinearAcceleration: Applies a constant linear acceleration in world space.ConstantLocalForce: Applies a constant force in local space.ConstantLocalTorque: Applies a constant torque in local space.ConstantLocalAngularAcceleration: Applies a constant angular acceleration in local space.
Tuple Fields
0: VectorImplementations
Methods from Deref<Target = Vector>
pub const ZERO: Vec3
pub const ONE: Vec3
pub const NEG_ONE: Vec3
pub const MIN: Vec3
pub const MAX: Vec3
pub const NAN: Vec3
pub const INFINITY: Vec3
pub const NEG_INFINITY: Vec3
pub const X: Vec3
pub const Y: Vec3
pub const Z: Vec3
pub const NEG_X: Vec3
pub const NEG_Y: Vec3
pub const NEG_Z: Vec3
pub const AXES: [Vec3; 3]
pub const USES_CORE_SIMD: bool = false
pub const USES_NEON: bool = false
pub const USES_SCALAR_MATH: bool = true
pub const USES_SSE2: bool = false
pub const USES_WASM_SIMD: bool = false
pub const USES_WASM32_SIMD: bool = false