RigidBodyForces

Trait RigidBodyForces 

pub trait RigidBodyForces: ReadRigidBodyForces + WriteRigidBodyForces { }
A trait for reading and writing forces of a dynamic rigid body.

This is implemented as a shared interface for the ForcesItem and NonWakingForcesItem returned by Forces.

See the documentation of Forces for more information on how to work with forces in Avian.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors